@@ -1,4 +1,4 @@
-// $Id: wxCatapultFrm.cpp,v 1.91 2006/07/30 17:20:59 manuelbi Exp $
+// $Id: wxCatapultFrm.cpp,v 1.93 2007/03/01 20:26:16 manuelbi Exp $
 // ----------------------------------------------------------------------------
 // headers
 // ----------------------------------------------------------------------------
@@ -287,7 +287,7 @@ void wxCatapultFrame::OnMenuAbout(wxCommandEvent& event)
 	);
 	version->SetLabel(msg);
 	description->SetLabel(wxT("The official GUI for openMSX"));
-	message->SetLabel(wxT("\251 2003-2006 The openMSX Team\n<openmsx-devel@lists.sourceforge.net>\n"));
+	message->SetLabel(wxT("\251 2003-2007 The openMSX Team\n<openmsx-devel@lists.sourceforge.net>\n"));
 #ifdef __WXMSW__
 		dlg.SetSize(-1,-1,400,307,0);
 #else
@@ -546,7 +546,7 @@ void wxCatapultFrame::SetFPSdisplay(wxString val)
 
 void wxCatapultFrame::OnUpdateFPS(wxTimerEvent& event)
 {
-	m_controller->WriteCommand(m_controller->GetInfoCommand(wxT("fps")));
+	m_controller->WriteCommand(wxT("openmsx_info fps"));
 }
 
 void wxCatapultFrame::OnEnableMainWindow(wxTimerEvent & event)
